========
Contents
========

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   index
   contributing
   authors
   history

.. toctree::
   :maxdepth: 2
   :name: Modules
   :caption: Modules

   processing
   variables
   distances
   utils


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
